"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _auth = require("../helpers/auth");
var _getUrlOrigin = _interopRequireDefault(require("../helpers/auth/getUrlOrigin"));
var _readConfigFile = require("../readConfigFile");
/* eslint-disable global-require */

function getTagInputFromSelectedTags(tags, inputString) {
  const selectedTag = [...tags].reverse().find(tag => tag.startsWith(inputString));
  let tagInput = null;
  if (selectedTag) {
    tagInput = selectedTag.split(`${inputString}_`).pop().toLowerCase();
  }
  return tagInput;
}
function getCustomAccountDetails(tags) {
  const tagsTobeFiltered = ['@profile', '@edition', '@beta', '@portal'];
  const filteredTags = tags.filter(tag => tagsTobeFiltered.some(prefix => tag.startsWith(prefix)));
  if (filteredTags && filteredTags.length > 0) {
    const portalInfo = getTagInputFromSelectedTags(filteredTags, '@portal');
    const betaFeature = getTagInputFromSelectedTags(filteredTags, '@beta');
    const profileInfo = getTagInputFromSelectedTags(filteredTags, '@profile');
    const editionInfo = getTagInputFromSelectedTags(filteredTags, '@edition');
    const user = (0, _auth.getUserForSelectedEditionAndProfile)(editionInfo, profileInfo, betaFeature, portalInfo);
    return user;
  }
  return null;
}
const {
  testSetup
} = (0, _readConfigFile.generateConfigFromFile)();
async function performDefaultPageSteps({
  context,
  $tags,
  page
}) {
  if (testSetup.page && typeof testSetup.page === 'function') {
    await testSetup.page({
      context,
      $tags,
      page
    });
  } else {
    await page.goto(process.env.domain);
  }
}
async function verifyPageIsLoaded(page) {
  const urlOrigin = (0, _getUrlOrigin.default)(page.url());
  const domainOrigin = (0, _getUrlOrigin.default)(process.env.domain);
  if (urlOrigin === domainOrigin) {
    return true;
  }
  return false;
}
var _default = exports.default = {
  page: async ({
    context,
    $tags,
    page
  }, use) => {
    const {
      isAuthMode
    } = (0, _readConfigFile.generateConfigFromFile)();
    if (!isAuthMode) {
      await use(page);
      return;
    }
    const testPortalDetails = getCustomAccountDetails($tags);
    if (testPortalDetails === null) {
      await performDefaultPageSteps({
        context,
        $tags,
        page
      });
      const user = (0, _auth.getDefaultActor)();
      process.env.actorInfo = JSON.stringify(user);
      await use(page);
    } else {
      await context.clearCookies();
      const {
        email,
        password
      } = testPortalDetails;
      await (0, _auth.performLoginSteps)({
        page,
        authFilePrefix: email,
        useremail: email,
        password: password
      }, async () => {
        return await verifyPageIsLoaded(page);
      });
      process.env.actorInfo = JSON.stringify(testPortalDetails);
      await performDefaultPageSteps({
        context,
        $tags,
        page
      });
      await use(page);
      await context.close();
    }
  }
};