import fs from 'fs';
import path from 'path';
import {
  test as teardown,
  expect
} from '@zohodesk/testinglibrary';
import { isDevelopmentSetup, loadCookiesIfPresent } from '@zohodesk/testinglibrary/helpers'
import getUrlOrigin from '../shared/url-helpers/getUrlOrigin';

// We are adding teardown logic only in CI mode
if (!isDevelopmentSetup()) {
  teardown(`Log out scenarios`, async ({ page }) => {
    const authDirectory = path.resolve(
      process.cwd(),
      'uat',
      'playwright',
      '.auth'
    );
    const files = fs.readdirSync(authDirectory);
    const promises = files.map(async file => {
      const authFilePath = path.join(authDirectory, file);
      await loadCookiesIfPresent(page, authFilePath);
      const domainOrigin = getUrlOrigin(process.env.domain);
      await page.goto(`${domainOrigin}/support/logout.sas `);
      await page.waitForNavigation();
      await expect(page.locator('[id="signin_flow"]')).toBeVisible();
      await fs.rmSync(authFilePath);
    });

    await Promise.all(promises);
  });
}
