async function get_cookie(page) {
  return page.evaluate(async () => {
    const results = document.cookie.match(`crmcsr=(.*?)(;|$)`);
    if (results) {
      return unescape(results[1]);
    }
    return null;
  });
}

async function getOnboardings({ page, cookieVal }) {
  return page.evaluate(
    async (cookieVal) =>
      fetch('/api/v1/onboardingStatus', {
        method: 'GET',
        headers: {
          orgId: window.currentOrg.id,
          'X-ZCSRF-TOKEN': `crmcsrfparam=${cookieVal}`
        }
      }).then((r) => (r.ok ? r.json() : Promise.reject(r))),
    cookieVal
  );
}

async function completeOnboardings({ page }) {
  const cookieVal = await get_cookie(page);
  const onboardings = await getOnboardings({ page });
  if (onboardings.pending.length) {
    await page.evaluate(
      async ({ cookieVal, onboardings }) =>
        fetch('/api/v1/onboardingStatus/markComplete', {
          method: 'POST',
          headers: {
            orgId: window.currentOrg.id,
            'X-ZCSRF-TOKEN': `crmcsrfparam=${cookieVal}`
          },
          body: JSON.stringify({ items: onboardings.pending })
        }),
      { cookieVal, onboardings }
    );
  }
}

module.exports = completeOnboardings;
